Shader /*ase_name*/ "Multi Pass/Hair" /*end*/
{
	Properties
	{
		_Cutout("Cutout", Range( 0 , 1)) = 0.5
		/*ase_props*/
	}
	
	SubShader
	{
		CGINCLUDE
		#pragma target 3.0 
		ENDCG

		Pass
		{
			Name "EarlyZ culling"
			Tags
			{
				"Queue" = "AlphaTest"
				"IgnoreProjector" = "True"
				"RenderType" = "TransparentCutout"
				"LightMode" = "ForwardBase"
			}
			Cull Back
			ZWrite On
			ZTest Less
			ColorMask A 

			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag
			#include "UnityCG.cginc"
			#include "AutoLight.cginc"
			#pragma multi_compile_fwdbase
			/*ase_pragma*/
			uniform float _Cutout;
			/*ase_globals*/

			struct appdata
			{
				float4 vertex : POSITION;
				float4 texcoord : TEXCOORD0;
				UNITY_VERTEX_INPUT_INSTANCE_ID
				/*ase_vdata:p=p;uv0=tc0.xyzw*/
			};
			
			struct v2f
			{
				float4 pos : SV_POSITION;
				UNITY_VERTEX_OUTPUT_STEREO
				/*ase_interp(1,):sp=sp.xyzw*/
			};

			v2f vert ( appdata v /*ase_vert_input*/)
			{
				v2f o;
				UNITY_INITIALIZE_OUTPUT(v2f,o);
				UNITY_SETUP_INSTANCE_ID(v);
				UNITY_INITIALIZE_VERTEX_OUTPUT_STEREO(o);
				
				/*ase_vert_code:v=appdata;o=v2f*/
				
				v.vertex.xyz += /*ase_vert_out:Local Vertex;Float3;_Vertex*/ float3(0,0,0) /*end*/;
				o.pos = UnityObjectToClipPos(v.vertex);
				#if ASE_SHADOWS
				TRANSFER_SHADOW(o);
				#endif
				return o;
			}
			
			float4 frag (v2f i /*ase_frag_input*/) : SV_Target
			{
				float outAlpha;

				/*ase_frag_code:i=v2f*/
				
				outAlpha = /*ase_frag_out:Alpha;Float;_Alpha*/1/*end*/;
				clip(outAlpha-_Cutout);
				return outAlpha;
			}
			ENDCG
		}

		Pass
		{
			/*ase_main_pass*/
			Name "Render Opaque"
			Tags
			{
				"Queue" = "AlphaTest"
				"IgnoreProjector" = "True"
				"RenderType" = "TransparentCutout"
				"LightMode" = "ForwardBase"
			}
			Cull Back
			ZWrite Off
			ZTest Equal
			ColorMask RGBA 

			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag
			#include "UnityCG.cginc"
			#include "AutoLight.cginc"
			#pragma multi_compile_fwdbase
			/*ase_pragma*/

			/*ase_globals*/

			struct appdata
			{
				float4 vertex : POSITION;
				float4 texcoord : TEXCOORD0;
				UNITY_VERTEX_INPUT_INSTANCE_ID
				/*ase_vdata:p=p;uv0=tc0.xyzw*/
			};
			
			struct v2f
			{
				float4 pos : SV_POSITION;
				UNITY_VERTEX_OUTPUT_STEREO
				/*ase_interp(1,):sp=sp.xyzw*/
			};

			v2f vert ( appdata v /*ase_vert_input*/)
			{
				v2f o;
				UNITY_INITIALIZE_OUTPUT(v2f,o);
				UNITY_SETUP_INSTANCE_ID(v);
				UNITY_INITIALIZE_VERTEX_OUTPUT_STEREO(o);
				
				/*ase_vert_code:v=appdata;o=v2f*/
				
				v.vertex.xyz += /*ase_vert_out:Local Vertex;Float3;_Vertex*/ float3(0,0,0) /*end*/;
				o.pos = UnityObjectToClipPos(v.vertex);
				#if ASE_SHADOWS
				TRANSFER_SHADOW(o);
				#endif
				return o;
			}
			
			float4 frag (v2f i /*ase_frag_input*/) : SV_Target
			{
				float3 outColor;
				float outAlpha;

				/*ase_frag_code:i=v2f*/
				
				outColor = /*ase_frag_out:Color;Float3;_Color*/float3(1,1,1)/*end*/;
				outAlpha = /*ase_frag_out:Alpha;Float;_Alpha*/1/*end*/;
				return float4(outColor,outAlpha);
			}
			ENDCG
		}

		Pass
		{
			Name "Render Back Transparent"
			Tags
			{
				"Queue" = "Transparent"
				"IgnoreProjector" = "True"
				"RenderType" = "Transparent"
				"LightMode" = "ForwardBase"
			}
			Cull Front
			ZWrite Off
			ZTest Less
			ColorMask RGBA 
			Blend SrcAlpha OneMinusSrcAlpha

			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag
			#include "UnityCG.cginc"
			#include "AutoLight.cginc"
			#pragma multi_compile_fwdbase
			/*ase_pragma*/

			/*ase_globals*/

			struct appdata
			{
				float4 vertex : POSITION;
				float4 texcoord : TEXCOORD0;
				UNITY_VERTEX_INPUT_INSTANCE_ID
				/*ase_vdata:p=p;uv0=tc0.xyzw*/
			};
			
			struct v2f
			{
				float4 pos : SV_POSITION;
				UNITY_VERTEX_OUTPUT_STEREO
				/*ase_interp(1,):sp=sp.xyzw*/
			};

			v2f vert ( appdata v /*ase_vert_input*/)
			{
				v2f o;
				UNITY_INITIALIZE_OUTPUT(v2f,o);
				UNITY_SETUP_INSTANCE_ID(v);
				UNITY_INITIALIZE_VERTEX_OUTPUT_STEREO(o);
				
				/*ase_vert_code:v=appdata;o=v2f*/
				
				v.vertex.xyz += /*ase_vert_out:Local Vertex;Float3;_Vertex*/ float3(0,0,0) /*end*/;
				o.pos = UnityObjectToClipPos(v.vertex);
				#if ASE_SHADOWS
				TRANSFER_SHADOW(o);
				#endif
				return o;
			}
			
			float4 frag (v2f i /*ase_frag_input*/) : SV_Target
			{
				float3 outColor;
				float outAlpha;

				/*ase_frag_code:i=v2f*/
				
				outColor = /*ase_frag_out:Color;Float3;_Color*/float3(1,1,1)/*end*/;
				outAlpha = /*ase_frag_out:Alpha;Float;_Alpha*/1/*end*/;
				return float4(outColor,outAlpha);
			}
			ENDCG
		}

		Pass
		{
			Name "Render Front Transparent"
			Tags
			{
				"Queue" = "Transparent"
				"IgnoreProjector" = "True"
				"RenderType" = "Transparent"
				"LightMode" = "ForwardBase"
			}
			Cull Back
			ZWrite On
			ZTest Less
			ColorMask RGBA 
			Blend SrcAlpha OneMinusSrcAlpha

			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag
			#include "UnityCG.cginc"
			#include "AutoLight.cginc"
			#pragma multi_compile_fwdbase
			/*ase_pragma*/

			/*ase_globals*/

			struct appdata
			{
				float4 vertex : POSITION;
				float4 texcoord : TEXCOORD0;
				UNITY_VERTEX_INPUT_INSTANCE_ID
				/*ase_vdata:p=p;uv0=tc0.xyzw*/
			};
			
			struct v2f
			{
				float4 pos : SV_POSITION;
				UNITY_VERTEX_OUTPUT_STEREO
				/*ase_interp(1,):sp=sp.xyzw*/
			};

			v2f vert ( appdata v /*ase_vert_input*/)
			{
				v2f o;
				UNITY_INITIALIZE_OUTPUT(v2f,o);
				UNITY_SETUP_INSTANCE_ID(v);
				UNITY_INITIALIZE_VERTEX_OUTPUT_STEREO(o);
				
				/*ase_vert_code:v=appdata;o=v2f*/
				
				v.vertex.xyz += /*ase_vert_out:Local Vertex;Float3;_Vertex*/ float3(0,0,0) /*end*/;
				o.pos = UnityObjectToClipPos(v.vertex);
				#if ASE_SHADOWS
				TRANSFER_SHADOW(o);
				#endif
				return o;
			}
			
			float4 frag (v2f i /*ase_frag_input*/) : SV_Target
			{
				float3 outColor;
				float outAlpha;

				/*ase_frag_code:i=v2f*/
				
				outColor = /*ase_frag_out:Color;Float3;_Color*/float3(1,1,1)/*end*/;
				outAlpha = /*ase_frag_out:Alpha;Float;_Alpha*/1/*end*/;
				return float4(outColor,outAlpha);
			}
			ENDCG
		}

		Pass
		{
			/*ase_hide_pass*/
			Name "ShadowCaster"
			Tags { "LightMode"="ShadowCaster" }
			ZWrite On 
			ZTest LEqual
			CGPROGRAM
			#pragma vertex vert
			#pragma fragment frag
			#pragma multi_compile_shadowcaster
			#define UNITY_PASS_SHADOWCASTER
			#include "UnityCG.cginc"
			/*ase_pragma*/
			uniform float _Cutout;
			/*ase_globals*/

			struct appdata
			{
				float4 vertex : POSITION;
				float3 normal : NORMAL;
				UNITY_VERTEX_INPUT_INSTANCE_ID
				/*ase_vdata:p=p;n=n*/
			};
			
			struct v2f
			{
				V2F_SHADOW_CASTER;
				UNITY_VERTEX_OUTPUT_STEREO
				/*ase_interp(1,):sp=sp.xyzw*/
			};

			
			v2f vert ( appdata v /*ase_vert_input*/)
			{
				v2f o;
				UNITY_INITIALIZE_OUTPUT(v2f,o);
				UNITY_SETUP_INSTANCE_ID(v);
				UNITY_INITIALIZE_VERTEX_OUTPUT_STEREO(o);
				
				/*ase_vert_code:v=appdata;o=v2f*/
				
				v.vertex.xyz += /*ase_vert_out:Local Vertex;Float3;_Vertex*/ float3(0,0,0) /*end*/;
				TRANSFER_SHADOW_CASTER_NORMALOFFSET(o)
				return o;
			}
			
			float4 frag (v2f i /*ase_frag_input*/) : SV_Target
			{
				float3 outColor;
				float outAlpha;

				/*ase_frag_code:i=v2f*/
				
				outColor = /*ase_frag_out:Color;Float3;_Color*/float3(1,1,1)/*end*/;
				outAlpha = /*ase_frag_out:Alpha;Float;_Alpha*/1/*end*/;
				clip(outAlpha-_Cutout);
				SHADOW_CASTER_FRAGMENT(i)
			}
			ENDCG
		}
	}
	CustomEditor "ASEMaterialInspector"
	Fallback "Diffuse"
}
